var indexSectionsWithContent =
{
  0: "abcdefghilmnoprstuvwx~",
  1: "acdeinprstx",
  2: "x",
  3: "adeinrstvx",
  4: "abcdefghilmnoprstvwx~",
  5: "it",
  6: "amps",
  7: "mn",
  8: "t",
  9: "o",
  10: "x",
  11: "adfghilnpstuwx"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "files",
  4: "functions",
  5: "variables",
  6: "typedefs",
  7: "enums",
  8: "enumvalues",
  9: "related",
  10: "defines",
  11: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Files",
  4: "Functions",
  5: "Variables",
  6: "Typedefs",
  7: "Enumerations",
  8: "Enumerator",
  9: "Friends",
  10: "Macros",
  11: "Pages"
};

